CVS commit: src/games/hack

2011-07-20 Thread David A. Holland
Module Name:src
Committed By:   dholland
Date:   Wed Jul 20 07:04:30 UTC 2011

Modified Files:
src/games/hack: hack.bones.c hack.do.c

Log Message:
Include system headers before private headers. Avoids various possible
symbol conflicts.


To generate a diff of this commit:
cvs rdiff -u -r1.8 -r1.9 src/games/hack/hack.bones.c
cvs rdiff -u -r1.9 -r1.10 src/games/hack/hack.do.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/games/hack/hack.bones.c
diff -u src/games/hack/hack.bones.c:1.8 src/games/hack/hack.bones.c:1.9
--- src/games/hack/hack.bones.c:1.8	Wed Aug 12 07:28:40 2009
+++ src/games/hack/hack.bones.c	Wed Jul 20 07:04:30 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: hack.bones.c,v 1.8 2009/08/12 07:28:40 dholland Exp $	*/
+/*	$NetBSD: hack.bones.c,v 1.9 2011/07/20 07:04:30 dholland Exp $	*/
 
 /*
  * Copyright (c) 1985, Stichting Centrum voor Wiskunde en Informatica,
@@ -63,13 +63,13 @@
 
 #include sys/cdefs.h
 #ifndef lint
-__RCSID($NetBSD: hack.bones.c,v 1.8 2009/08/12 07:28:40 dholland Exp $);
+__RCSID($NetBSD: hack.bones.c,v 1.9 2011/07/20 07:04:30 dholland Exp $);
 #endif/* not lint */
 
-#include hack.h
-#include extern.h
 #include fcntl.h
 #include unistd.h
+#include hack.h
+#include extern.h
 
 static char bones[] = bones_xx;
 

Index: src/games/hack/hack.do.c
diff -u src/games/hack/hack.do.c:1.9 src/games/hack/hack.do.c:1.10
--- src/games/hack/hack.do.c:1.9	Wed Aug 12 07:28:40 2009
+++ src/games/hack/hack.do.c	Wed Jul 20 07:04:30 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: hack.do.c,v 1.9 2009/08/12 07:28:40 dholland Exp $	*/
+/*	$NetBSD: hack.do.c,v 1.10 2011/07/20 07:04:30 dholland Exp $	*/
 
 /*
  * Copyright (c) 1985, Stichting Centrum voor Wiskunde en Informatica,
@@ -63,16 +63,16 @@
 
 #include sys/cdefs.h
 #ifndef lint
-__RCSID($NetBSD: hack.do.c,v 1.9 2009/08/12 07:28:40 dholland Exp $);
+__RCSID($NetBSD: hack.do.c,v 1.10 2011/07/20 07:04:30 dholland Exp $);
 #endif/* not lint */
 
 /* Contains code for 'd', 'D' (drop), '', '' (up, down) and 't' (throw) */
 
-#include hack.h
-#include extern.h
 #include fcntl.h
 #include unistd.h
 #include stdlib.h
+#include hack.h
+#include extern.h
 
 
 static int drop(struct obj *);



CVS commit: src/sys/arch/sparc64/dev

2011-07-20 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Wed Jul 20 10:39:43 UTC 2011

Modified Files:
src/sys/arch/sparc64/dev: schizo.c

Log Message:
some malloc() - kmem_alloc()


To generate a diff of this commit:
cvs rdiff -u -r1.23 -r1.24 src/sys/arch/sparc64/dev/schizo.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/sparc64/dev/schizo.c
diff -u src/sys/arch/sparc64/dev/schizo.c:1.23 src/sys/arch/sparc64/dev/schizo.c:1.24
--- src/sys/arch/sparc64/dev/schizo.c:1.23	Fri Jul  1 18:48:37 2011
+++ src/sys/arch/sparc64/dev/schizo.c	Wed Jul 20 10:39:43 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: schizo.c,v 1.23 2011/07/01 18:48:37 dyoung Exp $	*/
+/*	$NetBSD: schizo.c,v 1.24 2011/07/20 10:39:43 macallan Exp $	*/
 /*	$OpenBSD: schizo.c,v 1.55 2008/08/18 20:29:37 brad Exp $	*/
 
 /*
@@ -33,6 +33,7 @@
 #include sys/device.h
 #include sys/errno.h
 #include sys/extent.h
+#include sys/kmem.h
 #include sys/malloc.h
 #include sys/systm.h
 #include sys/time.h
@@ -169,7 +170,7 @@
 		   SCZ_ECCCTRL_CE_INTEN;
 	schizo_write(sc, SCZ_ECCCTRL, eccctrl);
 
-	pbm = malloc(sizeof(*pbm), M_DEVBUF, M_NOWAIT | M_ZERO);
+	pbm = kmem_zalloc(sizeof(*pbm), KM_NOSLEEP);
 	if (pbm == NULL)
 		panic(schizo: can't alloc schizo pbm);
 
@@ -250,10 +251,10 @@
 	pbm-sp_pc = schizo_alloc_chipset(pbm, sc-sc_node,
 	_sparc_pci_chipset);
 	pbm-sp_pc-spc_busmax = busranges[1];
-	pbm-sp_pc-spc_busnode = malloc(sizeof(*pbm-sp_pc-spc_busnode),
-	M_DEVBUF, M_NOWAIT | M_ZERO);
+	pbm-sp_pc-spc_busnode = kmem_zalloc(sizeof(*pbm-sp_pc-spc_busnode),
+	KM_NOSLEEP);
 	if (pbm-sp_pc-spc_busnode == NULL)
-		panic(schizo: malloc busnode);
+		panic(schizo: kmem_alloc busnode);
 
 	pba.pba_bus = busranges[0];
 	pba.pba_bridgetag = NULL;
@@ -452,9 +453,10 @@
 	}
 
 	/* give us a nice name.. */
-	name = (char *)malloc(32, M_DEVBUF, M_NOWAIT);
+	name = (char *)kmem_alloc(32, KM_NOSLEEP);
 	if (name == NULL)
-		panic(couldn't malloc iommu name);
+
+		panic(couldn't kmem_alloc iommu name);
 	snprintf(name, 32, %s dvma, device_xname(sc-sc_dev));
 
 	iommu_init(name, is, tsbsize, iobase);
@@ -521,7 +523,7 @@
 	mapoff, clroff));
 
 	ih = (struct intrhand *)
-		malloc(sizeof(struct intrhand), M_DEVBUF, M_NOWAIT);
+		kmem_alloc(sizeof(struct intrhand), KM_NOSLEEP);
 	if (ih == NULL)
 		return;
 	ih-ih_arg = arg;
@@ -564,8 +566,8 @@
 	struct schizo_softc *sc = pbm-sp_sc;
 	bus_space_tag_t bt;
 
-	bt = (bus_space_tag_t) malloc(sizeof(struct sparc_bus_space_tag),
-		M_DEVBUF, M_NOWAIT | M_ZERO);
+	bt = (bus_space_tag_t) kmem_zalloc(sizeof(struct sparc_bus_space_tag),
+		KM_NOSLEEP);
 	if (bt == NULL)
 		panic(schizo: could not allocate bus tag);
 
@@ -584,7 +586,7 @@
 	struct schizo_softc *sc = pbm-sp_sc;
 	bus_dma_tag_t dt, pdt = sc-sc_dmat;
 
-	dt = malloc(sizeof(*dt), M_DEVBUF, M_NOWAIT | M_ZERO);
+	dt = kmem_zalloc(sizeof(*dt), KM_NOSLEEP);
 	if (dt == NULL)
 		panic(schizo: could not alloc dma tag);
 
@@ -613,7 +615,7 @@
 {
 	pci_chipset_tag_t npc;
 
-	npc = malloc(sizeof *npc, M_DEVBUF, M_NOWAIT);
+	npc = kmem_alloc(sizeof *npc, KM_NOSLEEP);
 	if (npc == NULL)
 		panic(schizo: could not allocate pci_chipset_tag_t);
 	memcpy(npc, pc, sizeof *pc);
@@ -746,7 +748,7 @@
 	vec = INTVEC(ihandle);
 	ino = INTINO(vec);
 
-	ih = malloc(sizeof *ih, M_DEVBUF, M_NOWAIT);
+	ih = kmem_alloc(sizeof *ih, KM_NOSLEEP);
 	if (ih == NULL)
 		return (NULL);
 



CVS commit: src

2011-07-20 Thread Juergen Hannken-Illjes
Module Name:src
Committed By:   hannken
Date:   Wed Jul 20 11:52:00 UTC 2011

Modified Files:
src/sys/fs/msdosfs: msdosfs_vnops.c
src/tests/fs/vfs: t_vnops.c

Log Message:
Even though msdosfs never truncates file names it advertises _PC_NO_TRUNC
as zero.  Make it advertise one (no_trunc == true).

Names longer than NAME_MAX (255) will never pass namei() btw.

Fixes PR #43670 (msdosfs claims support for filenames longer than {NAME_MAX},
 but fails)


To generate a diff of this commit:
cvs rdiff -u -r1.77 -r1.78 src/sys/fs/msdosfs/msdosfs_vnops.c
cvs rdiff -u -r1.24 -r1.25 src/tests/fs/vfs/t_vnops.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/fs/msdosfs/msdosfs_vnops.c
diff -u src/sys/fs/msdosfs/msdosfs_vnops.c:1.77 src/sys/fs/msdosfs/msdosfs_vnops.c:1.78
--- src/sys/fs/msdosfs/msdosfs_vnops.c:1.77	Thu Jun 16 09:21:02 2011
+++ src/sys/fs/msdosfs/msdosfs_vnops.c	Wed Jul 20 11:52:00 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: msdosfs_vnops.c,v 1.77 2011/06/16 09:21:02 hannken Exp $	*/
+/*	$NetBSD: msdosfs_vnops.c,v 1.78 2011/07/20 11:52:00 hannken Exp $	*/
 
 /*-
  * Copyright (C) 1994, 1995, 1997 Wolfgang Solfrank.
@@ -48,7 +48,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: msdosfs_vnops.c,v 1.77 2011/06/16 09:21:02 hannken Exp $);
+__KERNEL_RCSID(0, $NetBSD: msdosfs_vnops.c,v 1.78 2011/07/20 11:52:00 hannken Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -1771,7 +1771,7 @@
 		*ap-a_retval = 1;
 		return (0);
 	case _PC_NO_TRUNC:
-		*ap-a_retval = 0;
+		*ap-a_retval = 1;
 		return (0);
 	case _PC_SYNC_IO:
 		*ap-a_retval = 1;

Index: src/tests/fs/vfs/t_vnops.c
diff -u src/tests/fs/vfs/t_vnops.c:1.24 src/tests/fs/vfs/t_vnops.c:1.25
--- src/tests/fs/vfs/t_vnops.c:1.24	Mon May 30 13:10:38 2011
+++ src/tests/fs/vfs/t_vnops.c	Wed Jul 20 11:52:00 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: t_vnops.c,v 1.24 2011/05/30 13:10:38 martin Exp $	*/
+/*	$NetBSD: t_vnops.c,v 1.25 2011/07/20 11:52:00 hannken Exp $	*/
 
 /*-
  * Copyright (c) 2010 The NetBSD Foundation, Inc.
@@ -439,8 +439,6 @@
 	if (val == -1)
 		atf_tc_fail_errno(pathconf);
 
-	if (FSTYPE_MSDOS(tc))
-		atf_tc_expect_fail(PR kern/43670);
 	fd = rump_sys_open(name, O_RDWR|O_CREAT, 0666);
 	if (val != 0  (fd != -1 || errno != ENAMETOOLONG))
 		atf_tc_fail_errno(open);
@@ -511,8 +509,6 @@
 	if (val == -1)
 		atf_tc_fail_errno(pathconf);
 
-	if (FSTYPE_MSDOS(tc))
-		atf_tc_expect_fail(PR kern/43670);
 	res = rump_sys_rename(dummy, name);
 	if (val != 0  (res != -1 || errno != ENAMETOOLONG))
 		atf_tc_fail_errno(rename);



CVS commit: src/sys/arch/luna68k/conf

2011-07-20 Thread Izumi Tsutsui
Module Name:src
Committed By:   tsutsui
Date:   Wed Jul 20 12:00:04 UTC 2011

Modified Files:
src/sys/arch/luna68k/conf: Makefile.luna68k

Log Message:
Fix thinko.  src/sys/conf/mkldscript.sh requires $OBJDUMP, not $ELF2AOUT.
(note generated faked a.out kernels can still be loaded and work fine)


To generate a diff of this commit:
cvs rdiff -u -r1.21 -r1.22 src/sys/arch/luna68k/conf/Makefile.luna68k

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/luna68k/conf/Makefile.luna68k
diff -u src/sys/arch/luna68k/conf/Makefile.luna68k:1.21 src/sys/arch/luna68k/conf/Makefile.luna68k:1.22
--- src/sys/arch/luna68k/conf/Makefile.luna68k:1.21	Sat Jul 16 15:52:21 2011
+++ src/sys/arch/luna68k/conf/Makefile.luna68k	Wed Jul 20 12:00:04 2011
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile.luna68k,v 1.21 2011/07/16 15:52:21 tsutsui Exp $
+#	$NetBSD: Makefile.luna68k,v 1.22 2011/07/20 12:00:04 tsutsui Exp $
 
 # Makefile for NetBSD
 #
@@ -60,7 +60,7 @@
 
 SYSTEM_LD_HEAD_EXTRA+=; \
 	( cat ${LUNA68K}/conf/kern.ldscript.head ; \
-	  ELF2AOUT=${ELF2AOUT} ${HOST_SH} $S/conf/mkldscript.sh \
+	  OBJDUMP=${OBJDUMP} ${HOST_SH} $S/conf/mkldscript.sh \
 	${SYSTEM_OBJ} ; \
 	  cat ${LUNA68K}/conf/kern.ldscript.tail )  ldscript
 



CVS commit: src/sys/arch/sparc64

2011-07-20 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Wed Jul 20 12:06:00 UTC 2011

Modified Files:
src/sys/arch/sparc64/dev: ebus.c psycho.c sbus.c schizo.c
src/sys/arch/sparc64/include: cpu.h
src/sys/arch/sparc64/sparc64: genassym.cf intr.c locore.s

Log Message:
add per ivec event counters


To generate a diff of this commit:
cvs rdiff -u -r1.58 -r1.59 src/sys/arch/sparc64/dev/ebus.c
cvs rdiff -u -r1.108 -r1.109 src/sys/arch/sparc64/dev/psycho.c
cvs rdiff -u -r1.88 -r1.89 src/sys/arch/sparc64/dev/sbus.c
cvs rdiff -u -r1.24 -r1.25 src/sys/arch/sparc64/dev/schizo.c
cvs rdiff -u -r1.96 -r1.97 src/sys/arch/sparc64/include/cpu.h
cvs rdiff -u -r1.65 -r1.66 src/sys/arch/sparc64/sparc64/genassym.cf
cvs rdiff -u -r1.63 -r1.64 src/sys/arch/sparc64/sparc64/intr.c
cvs rdiff -u -r1.335 -r1.336 src/sys/arch/sparc64/sparc64/locore.s

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/sparc64/dev/ebus.c
diff -u src/sys/arch/sparc64/dev/ebus.c:1.58 src/sys/arch/sparc64/dev/ebus.c:1.59
--- src/sys/arch/sparc64/dev/ebus.c:1.58	Fri Jul  1 18:48:36 2011
+++ src/sys/arch/sparc64/dev/ebus.c	Wed Jul 20 12:06:00 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: ebus.c,v 1.58 2011/07/01 18:48:36 dyoung Exp $	*/
+/*	$NetBSD: ebus.c,v 1.59 2011/07/20 12:06:00 macallan Exp $	*/
 
 /*
  * Copyright (c) 1999, 2000, 2001 Matthew R. Green
@@ -27,7 +27,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ebus.c,v 1.58 2011/07/01 18:48:36 dyoung Exp $);
+__KERNEL_RCSID(0, $NetBSD: ebus.c,v 1.59 2011/07/20 12:06:00 macallan Exp $);
 
 #include opt_ddb.h
 
@@ -285,7 +285,7 @@
 		ea-ea_reg[i].lo,
 		ea-ea_reg[i].lo + ea-ea_reg[i].size - 1);
 	for (i = 0; i  ea-ea_nintr; i++)
-		aprint_normal( ipl %d, ea-ea_intr[i]);
+		aprint_normal( ipl %x, ea-ea_intr[i]);
 	return (UNCONF);
 }
 

Index: src/sys/arch/sparc64/dev/psycho.c
diff -u src/sys/arch/sparc64/dev/psycho.c:1.108 src/sys/arch/sparc64/dev/psycho.c:1.109
--- src/sys/arch/sparc64/dev/psycho.c:1.108	Fri Jul  1 18:48:37 2011
+++ src/sys/arch/sparc64/dev/psycho.c	Wed Jul 20 12:06:00 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: psycho.c,v 1.108 2011/07/01 18:48:37 dyoung Exp $	*/
+/*	$NetBSD: psycho.c,v 1.109 2011/07/20 12:06:00 macallan Exp $	*/
 
 /*
  * Copyright (c) 1999, 2000 Matthew R. Green
@@ -55,7 +55,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: psycho.c,v 1.108 2011/07/01 18:48:37 dyoung Exp $);
+__KERNEL_RCSID(0, $NetBSD: psycho.c,v 1.109 2011/07/20 12:06:00 macallan Exp $);
 
 #include opt_ddb.h
 
@@ -1228,6 +1228,8 @@
 	if (ih == NULL)
 		return (NULL);
 
+	ih-ih_ivec = ihandle;
+
 	/*
 	 * Hunt through all the interrupt mapping regs to look for our
 	 * interrupt vector.

Index: src/sys/arch/sparc64/dev/sbus.c
diff -u src/sys/arch/sparc64/dev/sbus.c:1.88 src/sys/arch/sparc64/dev/sbus.c:1.89
--- src/sys/arch/sparc64/dev/sbus.c:1.88	Fri Jul  1 18:48:37 2011
+++ src/sys/arch/sparc64/dev/sbus.c	Wed Jul 20 12:06:00 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: sbus.c,v 1.88 2011/07/01 18:48:37 dyoung Exp $ */
+/*	$NetBSD: sbus.c,v 1.89 2011/07/20 12:06:00 macallan Exp $ */
 
 /*
  * Copyright (c) 1999-2002 Eduardo Horvath
@@ -34,7 +34,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: sbus.c,v 1.88 2011/07/01 18:48:37 dyoung Exp $);
+__KERNEL_RCSID(0, $NetBSD: sbus.c,v 1.89 2011/07/20 12:06:00 macallan Exp $);
 
 #include opt_ddb.h
 
@@ -578,6 +578,7 @@
 	ih-ih_fun = handler;
 	ih-ih_arg = arg;
 	ih-ih_number = vec;
+	ih-ih_ivec = 0;
 	ih-ih_pil = (1ipl);
 	intr_establish(ipl, level != IPL_VM, ih);
 	return (ih);

Index: src/sys/arch/sparc64/dev/schizo.c
diff -u src/sys/arch/sparc64/dev/schizo.c:1.24 src/sys/arch/sparc64/dev/schizo.c:1.25
--- src/sys/arch/sparc64/dev/schizo.c:1.24	Wed Jul 20 10:39:43 2011
+++ src/sys/arch/sparc64/dev/schizo.c	Wed Jul 20 12:06:00 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: schizo.c,v 1.24 2011/07/20 10:39:43 macallan Exp $	*/
+/*	$NetBSD: schizo.c,v 1.25 2011/07/20 12:06:00 macallan Exp $	*/
 /*	$OpenBSD: schizo.c,v 1.55 2008/08/18 20:29:37 brad Exp $	*/
 
 /*
@@ -768,6 +768,8 @@
 	DPRINTF(SDB_INTR, (%s: intr %x: %p mapoff % PRIx64  clroff %
 	PRIx64 \n, __func__, ino, intrlev[ino], mapoff, clroff));
 
+	ih-ih_ivec = ihandle;
+
 	intrregs = (uintptr_t)bus_space_vaddr(pbm-sp_regt, pbm-sp_intrh);
 	intrmapptr = (uint64_t *)(uintptr_t)(intrregs + mapoff);
 	intrclrptr = (uint64_t *)(uintptr_t)(intrregs + clroff);

Index: src/sys/arch/sparc64/include/cpu.h
diff -u src/sys/arch/sparc64/include/cpu.h:1.96 src/sys/arch/sparc64/include/cpu.h:1.97
--- src/sys/arch/sparc64/include/cpu.h:1.96	Wed Apr 13 03:40:00 2011
+++ src/sys/arch/sparc64/include/cpu.h	Wed Jul 20 12:06:00 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: cpu.h,v 1.96 2011/04/13 03:40:00 mrg Exp $ */
+/*	$NetBSD: cpu.h,v 1.97 2011/07/20 12:06:00 macallan Exp $ */
 
 /*
  * Copyright (c) 1992, 1993
@@ -331,6 +331,9 @@
 	struct intrhand		*ih_pending;	/* interrupt queued */
 	

CVS commit: src/sys/arch/evbppc/conf

2011-07-20 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Wed Jul 20 13:20:26 UTC 2011

Modified Files:
src/sys/arch/evbppc/conf: P2020RDB

Log Message:
Flash is only 16MB in size.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/sys/arch/evbppc/conf/P2020RDB

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbppc/conf/P2020RDB
diff -u src/sys/arch/evbppc/conf/P2020RDB:1.7 src/sys/arch/evbppc/conf/P2020RDB:1.8
--- src/sys/arch/evbppc/conf/P2020RDB:1.7	Tue Jul 19 19:57:02 2011
+++ src/sys/arch/evbppc/conf/P2020RDB	Wed Jul 20 13:20:26 2011
@@ -1,4 +1,4 @@
-#	$NetBSD: P2020RDB,v 1.7 2011/07/19 19:57:02 matt Exp $
+#	$NetBSD: P2020RDB,v 1.8 2011/07/20 13:20:26 matt Exp $
 #
 #	P2020RBD -- everything that's currently supported
 #
@@ -7,7 +7,7 @@
 
 options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-ident 		P2020RBD-$Revision: 1.7 $
+ident 		P2020RBD-$Revision: 1.8 $
 
 maxusers	32
 
@@ -156,7 +156,7 @@
 #options 	NOR_VERBOSE
 pq3cfi0 	at obio0 cs 0
 nor*		at pq3cfi?
-flash*		at nor? offset 0 size 0x800
+flash*		at nor? offset 0 size 0x100
 
 e500wdog*	at cpunode?		# Watchdog timer
 



CVS commit: src/sys/arch/evbppc/mpc85xx

2011-07-20 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Wed Jul 20 13:21:12 UTC 2011

Modified Files:
src/sys/arch/evbppc/mpc85xx: machdep.c

Log Message:
Suppress a GCC 4.5 warning.


To generate a diff of this commit:
cvs rdiff -u -r1.18 -r1.19 src/sys/arch/evbppc/mpc85xx/machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbppc/mpc85xx/machdep.c
diff -u src/sys/arch/evbppc/mpc85xx/machdep.c:1.18 src/sys/arch/evbppc/mpc85xx/machdep.c:1.19
--- src/sys/arch/evbppc/mpc85xx/machdep.c:1.18	Sun Jul 17 20:54:39 2011
+++ src/sys/arch/evbppc/mpc85xx/machdep.c	Wed Jul 20 13:21:12 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: machdep.c,v 1.18 2011/07/17 20:54:39 joerg Exp $	*/
+/*	$NetBSD: machdep.c,v 1.19 2011/07/20 13:21:12 matt Exp $	*/
 /*-
  * Copyright (c) 2010, 2011 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -122,8 +122,8 @@
 void	initppc(vaddr_t, vaddr_t, void *, void *, void *, void *);
 
 #define	MEMREGIONS	4
-phys_ram_seg_t physmemr[MEMREGIONS]; /* All memory */
-phys_ram_seg_t availmemr[MEMREGIONS];/* Available memory */
+phys_ram_seg_t physmemr[MEMREGIONS];		/* All memory */
+phys_ram_seg_t availmemr[2*MEMREGIONS];		/* Available memory */
 static u_int nmemr;
 
 #ifndef CONSFREQ
@@ -536,9 +536,10 @@
 	/*
 	 * Steal pages at the end of memory for the kernel message buffer.
 	 */
-	availmemr[cnt-1].size -= round_page(MSGBUFSIZE);
-	msgbuf_paddr =
-	(uintptr_t)(availmemr[cnt-1].start + availmemr[cnt-1].size);
+	mr = availmemr + cnt - 1;
+	KASSERT(mr-size = round_page(MSGBUFSIZE));
+	mr-size -= round_page(MSGBUFSIZE);
+	msgbuf_paddr = (uintptr_t)(mr-start + mr-size);
 
 	/*
 	 * Calculate physmem.



CVS commit: src/sys/dev/usb

2011-07-20 Thread Alan Barrett
Module Name:src
Committed By:   apb
Date:   Wed Jul 20 14:38:05 UTC 2011

Modified Files:
src/sys/dev/usb: usbdevs

Log Message:
Add Huawei E1820 Mobile Broadband USB cellular data adapter


To generate a diff of this commit:
cvs rdiff -u -r1.585 -r1.586 src/sys/dev/usb/usbdevs

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/usbdevs
diff -u src/sys/dev/usb/usbdevs:1.585 src/sys/dev/usb/usbdevs:1.586
--- src/sys/dev/usb/usbdevs:1.585	Tue Jul 19 06:52:33 2011
+++ src/sys/dev/usb/usbdevs	Wed Jul 20 14:38:04 2011
@@ -1,4 +1,4 @@
-$NetBSD: usbdevs,v 1.585 2011/07/19 06:52:33 jruoho Exp $
+$NetBSD: usbdevs,v 1.586 2011/07/20 14:38:04 apb Exp $
 
 /*
  * Copyright (c) 1998-2004 The NetBSD Foundation, Inc.
@@ -1487,6 +1487,7 @@
 product HUAWEI E220  		0x1003	Huawei E220
 product HUAWEI E1750INIT  	0x1446	Huawei E1750 USB CD
 product HUAWEI K3765  		0x1465	Huawei K3765
+product HUAWEI E1820  		0x14ac	Huawei E1820
 product HUAWEI K3765INIT 	0x1520	Huawei K3765 USB CD
 
 /* Huawei-3Com products */



CVS commit: src/sys/dev/usb

2011-07-20 Thread Alan Barrett
Module Name:src
Committed By:   apb
Date:   Wed Jul 20 14:40:23 UTC 2011

Modified Files:
src/sys/dev/usb: usbdevs.h usbdevs_data.h

Log Message:
regen for Huawei E1820


To generate a diff of this commit:
cvs rdiff -u -r1.578 -r1.579 src/sys/dev/usb/usbdevs.h
cvs rdiff -u -r1.579 -r1.580 src/sys/dev/usb/usbdevs_data.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/usbdevs.h
diff -u src/sys/dev/usb/usbdevs.h:1.578 src/sys/dev/usb/usbdevs.h:1.579
--- src/sys/dev/usb/usbdevs.h:1.578	Tue Jul 19 06:53:50 2011
+++ src/sys/dev/usb/usbdevs.h	Wed Jul 20 14:40:22 2011
@@ -1,10 +1,10 @@
-/*	$NetBSD: usbdevs.h,v 1.578 2011/07/19 06:53:50 jruoho Exp $	*/
+/*	$NetBSD: usbdevs.h,v 1.579 2011/07/20 14:40:22 apb Exp $	*/
 
 /*
  * THIS FILE IS AUTOMATICALLY GENERATED.  DO NOT EDIT.
  *
  * generated from:
- *	NetBSD: usbdevs,v 1.585 2011/07/19 06:52:33 jruoho Exp
+ *	NetBSD: usbdevs,v 1.586 2011/07/20 14:38:04 apb Exp
  */
 
 /*
@@ -1494,6 +1494,7 @@
 #define	USB_PRODUCT_HUAWEI_E220	0x1003		/* Huawei E220 */
 #define	USB_PRODUCT_HUAWEI_E1750INIT	0x1446		/* Huawei E1750 USB CD */
 #define	USB_PRODUCT_HUAWEI_K3765	0x1465		/* Huawei K3765 */
+#define	USB_PRODUCT_HUAWEI_E1820	0x14ac		/* Huawei E1820 */
 #define	USB_PRODUCT_HUAWEI_K3765INIT	0x1520		/* Huawei K3765 USB CD */
 
 /* Huawei-3Com products */

Index: src/sys/dev/usb/usbdevs_data.h
diff -u src/sys/dev/usb/usbdevs_data.h:1.579 src/sys/dev/usb/usbdevs_data.h:1.580
--- src/sys/dev/usb/usbdevs_data.h:1.579	Tue Jul 19 06:53:50 2011
+++ src/sys/dev/usb/usbdevs_data.h	Wed Jul 20 14:40:22 2011
@@ -1,10 +1,10 @@
-/*	$NetBSD: usbdevs_data.h,v 1.579 2011/07/19 06:53:50 jruoho Exp $	*/
+/*	$NetBSD: usbdevs_data.h,v 1.580 2011/07/20 14:40:22 apb Exp $	*/
 
 /*
  * THIS FILE IS AUTOMATICALLY GENERATED.  DO NOT EDIT.
  *
  * generated from:
- *	NetBSD: usbdevs,v 1.585 2011/07/19 06:52:33 jruoho Exp
+ *	NetBSD: usbdevs,v 1.586 2011/07/20 14:38:04 apb Exp
  */
 
 /*
@@ -4555,6 +4555,10 @@
 	Huawei K3765,
 	},
 	{
+	USB_VENDOR_HUAWEI, USB_PRODUCT_HUAWEI_E1820,
+	Huawei E1820,
+	},
+	{
 	USB_VENDOR_HUAWEI, USB_PRODUCT_HUAWEI_K3765INIT,
 	Huawei K3765 USB CD,
 	},
@@ -8455,4 +8459,4 @@
 	Prestige,
 	},
 };
-const int usb_nproducts = 1608;
+const int usb_nproducts = 1609;



CVS commit: src/sys/dev/usb

2011-07-20 Thread Alan Barrett
Module Name:src
Committed By:   apb
Date:   Wed Jul 20 14:41:39 UTC 2011

Modified Files:
src/sys/dev/usb: u3g.c

Log Message:
Make u3g driver recognise Huawei E1820.
(u3ginit already recognised it.)


To generate a diff of this commit:
cvs rdiff -u -r1.17 -r1.18 src/sys/dev/usb/u3g.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/u3g.c
diff -u src/sys/dev/usb/u3g.c:1.17 src/sys/dev/usb/u3g.c:1.18
--- src/sys/dev/usb/u3g.c:1.17	Thu Mar 10 00:13:56 2011
+++ src/sys/dev/usb/u3g.c	Wed Jul 20 14:41:39 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: u3g.c,v 1.17 2011/03/10 00:13:56 scw Exp $	*/
+/*	$NetBSD: u3g.c,v 1.18 2011/07/20 14:41:39 apb Exp $	*/
 
 /*-
  * Copyright (c) 2009 The NetBSD Foundation, Inc.
@@ -50,7 +50,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: u3g.c,v 1.17 2011/03/10 00:13:56 scw Exp $);
+__KERNEL_RCSID(0, $NetBSD: u3g.c,v 1.18 2011/07/20 14:41:39 apb Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -182,6 +182,7 @@
 static const struct usb_devno u3g_devs[] = {
 { USB_VENDOR_DELL, USB_PRODUCT_DELL_W5500 },
 	/* OEM: Huawei */
+	{ USB_VENDOR_HUAWEI, USB_PRODUCT_HUAWEI_E1820 },
 	{ USB_VENDOR_HUAWEI, USB_PRODUCT_HUAWEI_E220 },
 	{ USB_VENDOR_HUAWEI, USB_PRODUCT_HUAWEI_K3765 },
 	{ USB_VENDOR_HUAWEI, USB_PRODUCT_HUAWEI_MOBILE },



CVS commit: src/sys/dev/usb

2011-07-20 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Wed Jul 20 16:53:27 UTC 2011

Modified Files:
src/sys/dev/usb: usb.h

Log Message:
Add UIPROTO_RNDIS.


To generate a diff of this commit:
cvs rdiff -u -r1.91 -r1.92 src/sys/dev/usb/usb.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/usb.h
diff -u src/sys/dev/usb/usb.h:1.91 src/sys/dev/usb/usb.h:1.92
--- src/sys/dev/usb/usb.h:1.91	Tue Jan 18 08:29:24 2011
+++ src/sys/dev/usb/usb.h	Wed Jul 20 16:53:27 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: usb.h,v 1.91 2011/01/18 08:29:24 matt Exp $	*/
+/*	$NetBSD: usb.h,v 1.92 2011/07/20 16:53:27 jakllsch Exp $	*/
 /*	$FreeBSD: src/sys/dev/usb/usb.h,v 1.14 1999/11/17 22:33:46 n_hibma Exp $	*/
 
 /*
@@ -546,6 +546,7 @@
 #define UICLASS_WIRELESS	0xe0
 #define  UISUBCLASS_RF			0x01
 #define   UIPROTO_BLUETOOTH		0x01
+#define   UIPROTO_RNDIS			0x03
 
 #define UICLASS_APPL_SPEC	0xfe
 #define  UISUBCLASS_FIRMWARE_DOWNLOAD	1



CVS commit: src/sys/dev/usb

2011-07-20 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Wed Jul 20 17:06:01 UTC 2011

Modified Files:
src/sys/dev/usb: usbdevs

Log Message:
Add vendor HTC, and HTC and Samsung Android products.


To generate a diff of this commit:
cvs rdiff -u -r1.586 -r1.587 src/sys/dev/usb/usbdevs

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/usbdevs
diff -u src/sys/dev/usb/usbdevs:1.586 src/sys/dev/usb/usbdevs:1.587
--- src/sys/dev/usb/usbdevs:1.586	Wed Jul 20 14:38:04 2011
+++ src/sys/dev/usb/usbdevs	Wed Jul 20 17:06:00 2011
@@ -1,4 +1,4 @@
-$NetBSD: usbdevs,v 1.586 2011/07/20 14:38:04 apb Exp $
+$NetBSD: usbdevs,v 1.587 2011/07/20 17:06:00 jakllsch Exp $
 
 /*
  * Copyright (c) 1998-2004 The NetBSD Foundation, Inc.
@@ -397,6 +397,7 @@
 vendor O2MICRO		0x0b97	O2 Micro
 vendor USR		0x0baf	U.S. Robotics
 vendor AMBIT		0x0bb2	Ambit Microsystems
+vendor HTC		0x0bb4	HTC
 vendor REALTEK		0x0bda	Realtek
 vendor ADDONICS2	0x0bf6	Addonics Technology
 vendor FSC		0x0bf8	Fujitsu Siemens Computers
@@ -1482,6 +1483,9 @@
 /* HP products */
 product HP2 C500		0x6002	PhotoSmart C500
 
+/* HTC products */
+product HTC ANDROID		0x0ffe	Android
+
 /* Huawei Technologies products */
 product HUAWEI MOBILE		0x1001	Huawei Mobile
 product HUAWEI E220  		0x1003	Huawei E220
@@ -2360,7 +2364,9 @@
 product SAMSUNG MIGHTYDRIVE	0x1623	Mighty Drive
 product SAMSUNG RT2870_1	0x2018	RT2870
 product SAMSUNG ML6060		0x3008	ML-6060 laser printer
+product SAMSUNG ANDROID		0x6863	Android
 product SAMSUNG GTB3710		0x6876	GT-B3710 LTE/4G datacard
+product SAMSUNG ANDROID2	0x6881	Android
 product SAMSUNG GTB3730		0x689a	GT-B3730 LTE/4G datacard
 
 /* SanDisk products */



CVS commit: src/sys/dev/usb

2011-07-20 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Wed Jul 20 17:07:03 UTC 2011

Modified Files:
src/sys/dev/usb: usbdevs.h usbdevs_data.h

Log Message:
regen.


To generate a diff of this commit:
cvs rdiff -u -r1.579 -r1.580 src/sys/dev/usb/usbdevs.h
cvs rdiff -u -r1.580 -r1.581 src/sys/dev/usb/usbdevs_data.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/usbdevs.h
diff -u src/sys/dev/usb/usbdevs.h:1.579 src/sys/dev/usb/usbdevs.h:1.580
--- src/sys/dev/usb/usbdevs.h:1.579	Wed Jul 20 14:40:22 2011
+++ src/sys/dev/usb/usbdevs.h	Wed Jul 20 17:07:03 2011
@@ -1,10 +1,10 @@
-/*	$NetBSD: usbdevs.h,v 1.579 2011/07/20 14:40:22 apb Exp $	*/
+/*	$NetBSD: usbdevs.h,v 1.580 2011/07/20 17:07:03 jakllsch Exp $	*/
 
 /*
  * THIS FILE IS AUTOMATICALLY GENERATED.  DO NOT EDIT.
  *
  * generated from:
- *	NetBSD: usbdevs,v 1.586 2011/07/20 14:38:04 apb Exp
+ *	NetBSD: usbdevs,v 1.587 2011/07/20 17:06:00 jakllsch Exp
  */
 
 /*
@@ -404,6 +404,7 @@
 #define	USB_VENDOR_O2MICRO	0x0b97		/* O2 Micro */
 #define	USB_VENDOR_USR	0x0baf		/* U.S. Robotics */
 #define	USB_VENDOR_AMBIT	0x0bb2		/* Ambit Microsystems */
+#define	USB_VENDOR_HTC	0x0bb4		/* HTC */
 #define	USB_VENDOR_REALTEK	0x0bda		/* Realtek */
 #define	USB_VENDOR_ADDONICS2	0x0bf6		/* Addonics Technology */
 #define	USB_VENDOR_FSC	0x0bf8		/* Fujitsu Siemens Computers */
@@ -1489,6 +1490,9 @@
 /* HP products */
 #define	USB_PRODUCT_HP2_C500	0x6002		/* PhotoSmart C500 */
 
+/* HTC products */
+#define	USB_PRODUCT_HTC_ANDROID	0x0ffe		/* Android */
+
 /* Huawei Technologies products */
 #define	USB_PRODUCT_HUAWEI_MOBILE	0x1001		/* Huawei Mobile */
 #define	USB_PRODUCT_HUAWEI_E220	0x1003		/* Huawei E220 */
@@ -2367,7 +2371,9 @@
 #define	USB_PRODUCT_SAMSUNG_MIGHTYDRIVE	0x1623		/* Mighty Drive */
 #define	USB_PRODUCT_SAMSUNG_RT2870_1	0x2018		/* RT2870 */
 #define	USB_PRODUCT_SAMSUNG_ML6060	0x3008		/* ML-6060 laser printer */
+#define	USB_PRODUCT_SAMSUNG_ANDROID	0x6863		/* Android */
 #define	USB_PRODUCT_SAMSUNG_GTB3710	0x6876		/* GT-B3710 LTE/4G datacard */
+#define	USB_PRODUCT_SAMSUNG_ANDROID2	0x6881		/* Android */
 #define	USB_PRODUCT_SAMSUNG_GTB3730	0x689a		/* GT-B3730 LTE/4G datacard */
 
 /* SanDisk products */

Index: src/sys/dev/usb/usbdevs_data.h
diff -u src/sys/dev/usb/usbdevs_data.h:1.580 src/sys/dev/usb/usbdevs_data.h:1.581
--- src/sys/dev/usb/usbdevs_data.h:1.580	Wed Jul 20 14:40:22 2011
+++ src/sys/dev/usb/usbdevs_data.h	Wed Jul 20 17:07:03 2011
@@ -1,10 +1,10 @@
-/*	$NetBSD: usbdevs_data.h,v 1.580 2011/07/20 14:40:22 apb Exp $	*/
+/*	$NetBSD: usbdevs_data.h,v 1.581 2011/07/20 17:07:03 jakllsch Exp $	*/
 
 /*
  * THIS FILE IS AUTOMATICALLY GENERATED.  DO NOT EDIT.
  *
  * generated from:
- *	NetBSD: usbdevs,v 1.586 2011/07/20 14:38:04 apb Exp
+ *	NetBSD: usbdevs,v 1.587 2011/07/20 17:06:00 jakllsch Exp
  */
 
 /*
@@ -1395,6 +1395,10 @@
 	Ambit Microsystems,
 	},
 	{
+	USB_VENDOR_HTC,
+	HTC,
+	},
+	{
 	USB_VENDOR_REALTEK,
 	Realtek,
 	},
@@ -2019,7 +2023,7 @@
 	GNU Radio USRP,
 	},
 };
-const int usb_nvendors = 495;
+const int usb_nvendors = 496;
 
 const struct usb_product usb_products[] = {
 	{
@@ -4539,6 +4543,10 @@
 	PhotoSmart C500,
 	},
 	{
+	USB_VENDOR_HTC, USB_PRODUCT_HTC_ANDROID,
+	Android,
+	},
+	{
 	USB_VENDOR_HUAWEI, USB_PRODUCT_HUAWEI_MOBILE,
 	Huawei Mobile,
 	},
@@ -7059,10 +7067,18 @@
 	ML-6060 laser printer,
 	},
 	{
+	USB_VENDOR_SAMSUNG, USB_PRODUCT_SAMSUNG_ANDROID,
+	Android,
+	},
+	{
 	USB_VENDOR_SAMSUNG, USB_PRODUCT_SAMSUNG_GTB3710,
 	GT-B3710 LTE/4G datacard,
 	},
 	{
+	USB_VENDOR_SAMSUNG, USB_PRODUCT_SAMSUNG_ANDROID2,
+	Android,
+	},
+	{
 	USB_VENDOR_SAMSUNG, USB_PRODUCT_SAMSUNG_GTB3730,
 	GT-B3730 LTE/4G datacard,
 	},
@@ -8459,4 +8475,4 @@
 	Prestige,
 	},
 };
-const int usb_nproducts = 1609;
+const int usb_nproducts = 1612;



CVS commit: src/lib/libc/sys

2011-07-20 Thread Nicolas Joly
Module Name:src
Committed By:   njoly
Date:   Wed Jul 20 17:51:25 UTC 2011

Modified Files:
src/lib/libc/sys: getdents.2

Log Message:
Remove unneeded `Either' word in EFAULT error description.


To generate a diff of this commit:
cvs rdiff -u -r1.22 -r1.23 src/lib/libc/sys/getdents.2

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/sys/getdents.2
diff -u src/lib/libc/sys/getdents.2:1.22 src/lib/libc/sys/getdents.2:1.23
--- src/lib/libc/sys/getdents.2:1.22	Fri Jun  4 05:42:24 2010
+++ src/lib/libc/sys/getdents.2	Wed Jul 20 17:51:25 2011
@@ -1,4 +1,4 @@
-.\	$NetBSD: getdents.2,v 1.22 2010/06/04 05:42:24 jruoho Exp $
+.\	$NetBSD: getdents.2,v 1.23 2011/07/20 17:51:25 njoly Exp $
 .\
 .\ Copyright (c) 1989, 1991, 1993
 .\	The Regents of the University of California.  All rights reserved.
@@ -111,7 +111,6 @@
 .Fa fd
 is not a valid file descriptor open for reading.
 .It Bq Er EFAULT
-Either
 .Fa buf
 points outside the allocated address space.
 .It Bq Er EINVAL



CVS commit: src/external/cddl/osnet/dev/dtrace/i386

2011-07-20 Thread Matthias Scheler
Module Name:src
Committed By:   tron
Date:   Wed Jul 20 19:51:57 UTC 2011

Modified Files:
src/external/cddl/osnet/dev/dtrace/i386: dis_tables.c

Log Message:
Fix uninitialized variables reported by GCC 4.5.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/external/cddl/osnet/dev/dtrace/i386/dis_tables.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/cddl/osnet/dev/dtrace/i386/dis_tables.c
diff -u src/external/cddl/osnet/dev/dtrace/i386/dis_tables.c:1.2 src/external/cddl/osnet/dev/dtrace/i386/dis_tables.c:1.3
--- src/external/cddl/osnet/dev/dtrace/i386/dis_tables.c:1.2	Sun Feb 21 01:46:33 2010
+++ src/external/cddl/osnet/dev/dtrace/i386/dis_tables.c	Wed Jul 20 19:51:57 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: dis_tables.c,v 1.2 2010/02/21 01:46:33 darran Exp $	*/
+/*	$NetBSD: dis_tables.c,v 1.3 2011/07/20 19:51:57 tron Exp $	*/
 
 /*
  * CDDL HEADER START
@@ -1716,9 +1716,9 @@
 	uint_t opcode2;		/* low nibble of 1st byte */
 	uint_t opcode3;		/* extra opcode bits usually from ModRM byte */
 	uint_t opcode4;		/* high nibble of 2nd byte */
-	uint_t opcode5;		/* low nibble of 2ne byte */
+	uint_t opcode5 = 0xff;	/* low nibble of 2nd byte */
 	uint_t opcode6;		/* high nibble of 3rd byte */
-	uint_t opcode7;		/* low nibble of 3rd byte */
+	uint_t opcode7 = 0xff;	/* low nibble of 3rd byte */
 	uint_t opcode_bytes = 1;
 
 	/*



CVS commit: src/sys/dev/usb

2011-07-20 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Wed Jul 20 19:59:50 UTC 2011

Added Files:
src/sys/dev/usb: if_urndis.c if_urndisreg.h

Log Message:
Add urndis(4) driver for USB networking devices implementing the
Microsoft RNDIS specification.  From OpenBSD.


To generate a diff of this commit:
cvs rdiff -u -r0 -r1.1 src/sys/dev/usb/if_urndis.c \
src/sys/dev/usb/if_urndisreg.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Added files:

Index: src/sys/dev/usb/if_urndis.c
diff -u /dev/null src/sys/dev/usb/if_urndis.c:1.1
--- /dev/null	Wed Jul 20 19:59:50 2011
+++ src/sys/dev/usb/if_urndis.c	Wed Jul 20 19:59:49 2011
@@ -0,0 +1,1544 @@
+/*	$NetBSD: if_urndis.c,v 1.1 2011/07/20 19:59:49 jakllsch Exp $ */
+/*	$OpenBSD: if_urndis.c,v 1.31 2011/07/03 15:47:17 matthew Exp $ */
+
+/*
+ * Copyright (c) 2010 Jonathan Armani arm...@openbsd.org
+ * Copyright (c) 2010 Fabien Romano fab...@openbsd.org
+ * Copyright (c) 2010 Michael Knudsen m...@openbsd.org
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
+ *
+ * THE SOFTWARE IS PROVIDED AS IS AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+ * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+ * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+ * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+ * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ */
+
+#include sys/cdefs.h
+__KERNEL_RCSID(0, $NetBSD: if_urndis.c,v 1.1 2011/07/20 19:59:49 jakllsch Exp $);
+
+#include sys/param.h
+#include sys/systm.h
+#include sys/sockio.h
+#include sys/rwlock.h
+#include sys/mbuf.h
+#include sys/kmem.h
+#include sys/kernel.h
+#include sys/proc.h
+#include sys/socket.h
+#include sys/device.h
+
+#include net/if.h
+#include net/if_dl.h
+#include net/if_media.h
+#include net/if_ether.h
+
+#include net/bpf.h
+
+#include sys/bus.h
+#include dev/usb/usb.h
+#include dev/usb/usbdi.h
+#include dev/usb/usbdi_util.h
+#include dev/usb/usbdivar.h
+#include dev/usb/usbdevs.h
+#include dev/usb/usbcdc.h
+
+#include dev/usb/if_urndisreg.h
+
+#ifdef URNDIS_DEBUG
+#define DPRINTF(x)  do { printf x; } while (0)
+#else
+#define DPRINTF(x)
+#endif
+
+#define DEVNAME(sc)	(device_xname(sc-sc_dev))
+
+#define ETHER_ALIGN 2
+#define URNDIS_RESPONSE_LEN 0x400
+
+
+static int urndis_newbuf(struct urndis_softc *, struct urndis_chain *);
+
+static int urndis_ioctl(struct ifnet *, unsigned long, void *);
+#if 0
+static void urndis_watchdog(struct ifnet *);
+#endif
+
+static void urndis_start(struct ifnet *);
+static void urndis_rxeof(usbd_xfer_handle, usbd_private_handle, usbd_status);
+static void urndis_txeof(usbd_xfer_handle, usbd_private_handle, usbd_status);
+static int urndis_rx_list_init(struct urndis_softc *);
+static int urndis_tx_list_init(struct urndis_softc *);
+
+static void urndis_init(struct ifnet *);
+static void urndis_stop(struct ifnet *);
+
+static usbd_status urndis_ctrl_msg(struct urndis_softc *, uint8_t, uint8_t,
+uint16_t, uint16_t, void *, size_t);
+static usbd_status urndis_ctrl_send(struct urndis_softc *, void *, size_t);
+static struct urndis_comp_hdr *urndis_ctrl_recv(struct urndis_softc *);
+
+static uint32_t urndis_ctrl_handle(struct urndis_softc *,
+struct urndis_comp_hdr *, void **, size_t *);
+static uint32_t urndis_ctrl_handle_init(struct urndis_softc *,
+const struct urndis_comp_hdr *);
+static uint32_t urndis_ctrl_handle_query(struct urndis_softc *,
+const struct urndis_comp_hdr *, void **, size_t *);
+static uint32_t urndis_ctrl_handle_reset(struct urndis_softc *,
+const struct urndis_comp_hdr *);
+
+static uint32_t urndis_ctrl_init(struct urndis_softc *);
+#if 0
+static uint32_t urndis_ctrl_halt(struct urndis_softc *);
+#endif
+static uint32_t urndis_ctrl_query(struct urndis_softc *, uint32_t, void *,
+size_t, void **, size_t *);
+static uint32_t urndis_ctrl_set(struct urndis_softc *, uint32_t, void *, size_t);
+#if 0
+static uint32_t urndis_ctrl_set_param(struct urndis_softc *, const char *,
+uint32_t, void *, size_t);
+static uint32_t urndis_ctrl_reset(struct urndis_softc *);
+static uint32_t urndis_ctrl_keepalive(struct urndis_softc *);
+#endif
+
+static int urndis_encap(struct urndis_softc *, struct mbuf *, int);
+static void urndis_decap(struct urndis_softc *, struct urndis_chain *, uint32_t);
+
+static int urndis_match(device_t, cfdata_t, void *);
+static void urndis_attach(device_t, device_t, void *);
+static int urndis_detach(device_t, int);
+static int urndis_activate(device_t, enum devact);
+
+CFATTACH_DECL_NEW(urndis, sizeof(struct 

CVS commit: src/sys/arch

2011-07-20 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Wed Jul 20 20:27:42 UTC 2011

Modified Files:
src/sys/arch/amd64/conf: XEN3_DOM0
src/sys/arch/i386/conf: XEN3_DOM0

Log Message:
Add urndis(4).


To generate a diff of this commit:
cvs rdiff -u -r1.68 -r1.69 src/sys/arch/amd64/conf/XEN3_DOM0
cvs rdiff -u -r1.52 -r1.53 src/sys/arch/i386/conf/XEN3_DOM0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/amd64/conf/XEN3_DOM0
diff -u src/sys/arch/amd64/conf/XEN3_DOM0:1.68 src/sys/arch/amd64/conf/XEN3_DOM0:1.69
--- src/sys/arch/amd64/conf/XEN3_DOM0:1.68	Sat May 28 16:58:51 2011
+++ src/sys/arch/amd64/conf/XEN3_DOM0	Wed Jul 20 20:27:41 2011
@@ -1,4 +1,4 @@
-# $NetBSD: XEN3_DOM0,v 1.68 2011/05/28 16:58:51 ryo Exp $
+# $NetBSD: XEN3_DOM0,v 1.69 2011/07/20 20:27:41 jakllsch Exp $
 
 include 	arch/amd64/conf/std.xen
 
@@ -612,6 +612,7 @@
 kue*	at uhub? port ?		# Kawasaki LSI KL5KUSB101B based adapters
 udav*	at uhub? port ?		# Davicom DM9601 based adapters
 url*	at uhub? port ?		# Realtek RTL8150L based adapters
+urndis* at uhub? port ?		# Microsoft RNDIS specification
 
 # USB 802.11 adapters
 atu*	at uhub? port ?		# Atmel AT76C50XX based adapters

Index: src/sys/arch/i386/conf/XEN3_DOM0
diff -u src/sys/arch/i386/conf/XEN3_DOM0:1.52 src/sys/arch/i386/conf/XEN3_DOM0:1.53
--- src/sys/arch/i386/conf/XEN3_DOM0:1.52	Sat May 28 13:01:50 2011
+++ src/sys/arch/i386/conf/XEN3_DOM0	Wed Jul 20 20:27:42 2011
@@ -1,4 +1,4 @@
-#	$NetBSD: XEN3_DOM0,v 1.52 2011/05/28 13:01:50 ryo Exp $
+#	$NetBSD: XEN3_DOM0,v 1.53 2011/07/20 20:27:42 jakllsch Exp $
 #
 #	XEN3_0: Xen 3.0 domain0 kernel
 
@@ -590,6 +590,7 @@
 kue*	at uhub? port ?		# Kawasaki LSI KL5KUSB101B based adapters
 udav*	at uhub? port ?		# Davicom DM9601 based adapters
 url*	at uhub? port ?		# Realtek RTL8150L based adapters
+urndis*	at uhub? port ?		# Microsoft RNDIS specification
 
 # USB 802.11 adapters
 atu*	at uhub? port ?		# Atmel AT76C50XX based adapters



CVS commit: src/sys/arch

2011-07-20 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Wed Jul 20 20:29:54 UTC 2011

Modified Files:
src/sys/arch/amd64/conf: GENERIC
src/sys/arch/i386/conf: ALL GENERIC

Log Message:
Add cxdtv(4) and urndis(4).  Also, two slight cosmetic changes.


To generate a diff of this commit:
cvs rdiff -u -r1.323 -r1.324 src/sys/arch/amd64/conf/GENERIC
cvs rdiff -u -r1.313 -r1.314 src/sys/arch/i386/conf/ALL
cvs rdiff -u -r1.1039 -r1.1040 src/sys/arch/i386/conf/GENERIC

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/amd64/conf/GENERIC
diff -u src/sys/arch/amd64/conf/GENERIC:1.323 src/sys/arch/amd64/conf/GENERIC:1.324
--- src/sys/arch/amd64/conf/GENERIC:1.323	Wed Jul 13 07:52:49 2011
+++ src/sys/arch/amd64/conf/GENERIC	Wed Jul 20 20:29:54 2011
@@ -1,4 +1,4 @@
-# $NetBSD: GENERIC,v 1.323 2011/07/13 07:52:49 jruoho Exp $
+# $NetBSD: GENERIC,v 1.324 2011/07/20 20:29:54 jakllsch Exp $
 #
 # GENERIC machine description file
 #
@@ -22,7 +22,7 @@
 
 options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-#ident 		GENERIC-$Revision: 1.323 $
+#ident 		GENERIC-$Revision: 1.324 $
 
 maxusers	64		# estimated number of users
 
@@ -869,8 +869,9 @@
 cdce*	at uhub? port ?		# CDC, Ethernet Networking Control Model
 cue*	at uhub? port ?		# CATC USB-EL1201A based adapters
 kue*	at uhub? port ?		# Kawasaki LSI KL5KUSB101B based adapters
-url*	at uhub? port ?		# Realtek RTL8150L based adapters
 udav*	at uhub? port ?		# Davicom DM9601 based adapters
+url*	at uhub? port ?		# Realtek RTL8150L based adapters
+urndis*	at uhub? port ?		# Microsoft RNDIS specification
 
 # Prolific PL2301/PL2302 host-to-host adapter
 upl*	at uhub? port ?
@@ -1036,6 +1037,10 @@
 bktr* at pci? dev ? function ?
 radio* at bktr?
 
+# Conexant CX2388[0-3]-based DTV cards
+cxdtv* at pci? dev ? function ?
+#iic* at cxdtv?
+
 
 # Bluetooth Controller and Device support
 

Index: src/sys/arch/i386/conf/ALL
diff -u src/sys/arch/i386/conf/ALL:1.313 src/sys/arch/i386/conf/ALL:1.314
--- src/sys/arch/i386/conf/ALL:1.313	Tue Jul 19 21:02:23 2011
+++ src/sys/arch/i386/conf/ALL	Wed Jul 20 20:29:54 2011
@@ -1,4 +1,4 @@
-# $NetBSD: ALL,v 1.313 2011/07/19 21:02:23 jmcneill Exp $
+# $NetBSD: ALL,v 1.314 2011/07/20 20:29:54 jakllsch Exp $
 # From NetBSD: GENERIC,v 1.787 2006/10/01 18:37:54 bouyer Exp
 #
 # ALL machine description file
@@ -17,7 +17,7 @@
 
 options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-#ident 		ALL-$Revision: 1.313 $
+#ident 		ALL-$Revision: 1.314 $
 
 maxusers	64		# estimated number of users
 
@@ -1266,6 +1266,7 @@
 kue*	at uhub? port ?		# Kawasaki LSI KL5KUSB101B based adapters
 udav*	at uhub? port ?		# Davicom DM9601 based adapters
 url*	at uhub? port ?		# Realtek RTL8150L based adapters
+urndis* at uhub? port ?		# Microsoft RNDIS specification
 
 # USB 802.11 adapters
 atu*	at uhub? port ?		# Atmel AT76C50XX based adapters
@@ -1504,6 +1505,10 @@
 bktr*	at pci? dev ? function ?
 radio*	at bktr?
 
+# Conexant CX2388[0-3]-based DTV cards
+cxdtv*	at pci? dev ? function ?
+iic*	at cxdtv?
+
 isv*	at isa? port 0x3e0		# IDEC Supervision/16 image capture
 
 # Bluetooth Controller and Device support

Index: src/sys/arch/i386/conf/GENERIC
diff -u src/sys/arch/i386/conf/GENERIC:1.1039 src/sys/arch/i386/conf/GENERIC:1.1040
--- src/sys/arch/i386/conf/GENERIC:1.1039	Tue Jul 19 21:02:25 2011
+++ src/sys/arch/i386/conf/GENERIC	Wed Jul 20 20:29:54 2011
@@ -1,4 +1,4 @@
-# $NetBSD: GENERIC,v 1.1039 2011/07/19 21:02:25 jmcneill Exp $
+# $NetBSD: GENERIC,v 1.1040 2011/07/20 20:29:54 jakllsch Exp $
 #
 # GENERIC machine description file
 #
@@ -22,7 +22,7 @@
 
 options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-#ident 		GENERIC-$Revision: 1.1039 $
+#ident 		GENERIC-$Revision: 1.1040 $
 
 maxusers	64		# estimated number of users
 
@@ -1202,7 +1202,7 @@
 ustir*	at uhub? port ?
 irframe* at ustir?
 
-# Windows Media Center IR tranceiver
+# Windows Media Center IR transceiver
 irmce*	at uhub? port ?
 cir*	at irmce?
 
@@ -1214,6 +1214,7 @@
 kue*	at uhub? port ?		# Kawasaki LSI KL5KUSB101B based adapters
 udav*	at uhub? port ?		# Davicom DM9601 based adapters
 url*	at uhub? port ?		# Realtek RTL8150L based adapters
+urndis*	at uhub? port ?		# Microsoft RNDIS specification
 
 # USB 802.11 adapters
 atu*	at uhub? port ?		# Atmel AT76C50XX based adapters
@@ -1439,6 +1440,9 @@
 bktr*	at pci? dev ? function ?
 radio*	at bktr?
 
+# Conexant CX2388[0-3]-based DTV cards
+cxdtv*	at pci? dev ? function ?
+#iic*	at cxdtv?
 
 # Bluetooth Controller and Device support
 



CVS commit: src/doc

2011-07-20 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Wed Jul 20 20:38:29 UTC 2011

Modified Files:
src/doc: CHANGES

Log Message:
Note the two new drivers I recently worked on.


To generate a diff of this commit:
cvs rdiff -u -r1.1580 -r1.1581 src/doc/CHANGES

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES
diff -u src/doc/CHANGES:1.1580 src/doc/CHANGES:1.1581
--- src/doc/CHANGES:1.1580	Mon Jul 18 11:55:08 2011
+++ src/doc/CHANGES	Wed Jul 20 20:38:29 2011
@@ -1,4 +1,4 @@
-# LIST OF CHANGES FROM LAST RELEASE:			$Revision: 1.1580 $
+# LIST OF CHANGES FROM LAST RELEASE:			$Revision: 1.1581 $
 #
 #
 # [Note: This file does not mention every change made to the NetBSD source tree.
@@ -1061,6 +1061,8 @@
 		for AR71xx (24K) and AR9344 (74K) SoCs.
 	dtv(4): Add digital TV framework. [jmcneill 20110709]
 	auvitek(4): Add digital capture support. [jmcneill 20110709]
+	cxdtv(4): Add driver for Conexant CX23880-based DTV cards.
+		[jakllsch 20110711]
 	hpacel(4): Add a driver for HP 3D DriveGuard; a LIS3LV02DL-based
 		accelerometer. [jruoho 20110713]
 	emdtv(4): Add a driver for Empia EM28xx family USB video
@@ -1077,3 +1079,5 @@
 		[tsutsui 20110716]
 	luna68k: Build a ramdisk based INSTALL kernel with sysinst(8).
 		[tsutsui 20110716]
+	urndis(4): Add driver for Microsoft RNDIS-based USB networking devices,
+		such as Android-based phones. From OpenBSD. [jakllsch 20110720]



CVS commit: src/sys/arch/hpcsh

2011-07-20 Thread David Young
Module Name:src
Committed By:   dyoung
Date:   Wed Jul 20 20:46:50 UTC 2011

Modified Files:
src/sys/arch/hpcsh/dev/hd64461: hd64461pcmcia.c
src/sys/arch/hpcsh/hpcsh: bus_space.c
Added Files:
src/sys/arch/hpcsh/include: bus_util.h

Log Message:
Move macros _BUS_SPACE_WRITE(), _BUS_SPACE_WRITE_MULTI(), et
cetera, into hpcsh/bus_util.h for both hpcsh/bus_space.c and
dev/hd64461/hd64461pcmcia.c to use them.

(I haven't had a close look at what hd64461pcmcia.c is doing, but I have
a hunch that it is a good use for bus_space_tag_create(9).)


To generate a diff of this commit:
cvs rdiff -u -r1.47 -r1.48 src/sys/arch/hpcsh/dev/hd64461/hd64461pcmcia.c
cvs rdiff -u -r1.17 -r1.18 src/sys/arch/hpcsh/hpcsh/bus_space.c
cvs rdiff -u -r0 -r1.1 src/sys/arch/hpcsh/include/bus_util.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/hpcsh/dev/hd64461/hd64461pcmcia.c
diff -u src/sys/arch/hpcsh/dev/hd64461/hd64461pcmcia.c:1.47 src/sys/arch/hpcsh/dev/hd64461/hd64461pcmcia.c:1.48
--- src/sys/arch/hpcsh/dev/hd64461/hd64461pcmcia.c:1.47	Tue Jul 19 15:30:52 2011
+++ src/sys/arch/hpcsh/dev/hd64461/hd64461pcmcia.c	Wed Jul 20 20:46:49 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: hd64461pcmcia.c,v 1.47 2011/07/19 15:30:52 dyoung Exp $	*/
+/*	$NetBSD: hd64461pcmcia.c,v 1.48 2011/07/20 20:46:49 dyoung Exp $	*/
 
 /*-
  * Copyright (c) 2001, 2002, 2004 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: hd64461pcmcia.c,v 1.47 2011/07/19 15:30:52 dyoung Exp $);
+__KERNEL_RCSID(0, $NetBSD: hd64461pcmcia.c,v 1.48 2011/07/20 20:46:49 dyoung Exp $);
 
 #include opt_hd64461pcmcia.h
 
@@ -57,6 +57,8 @@
 #include hpcsh/dev/hd64461/hd64461pcmciavar.h
 #include hpcsh/dev/hd64461/hd64461pcmciareg.h
 
+#include hpcsh/bus_util.h	/* for _BUS_SPACE_WRITE(), et cetera */
+
 #include locators.h
 
 #ifdef	HD64461PCMCIA_DEBUG

Index: src/sys/arch/hpcsh/hpcsh/bus_space.c
diff -u src/sys/arch/hpcsh/hpcsh/bus_space.c:1.17 src/sys/arch/hpcsh/hpcsh/bus_space.c:1.18
--- src/sys/arch/hpcsh/hpcsh/bus_space.c:1.17	Tue Jul 19 15:30:53 2011
+++ src/sys/arch/hpcsh/hpcsh/bus_space.c	Wed Jul 20 20:46:49 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: bus_space.c,v 1.17 2011/07/19 15:30:53 dyoung Exp $	*/
+/*	$NetBSD: bus_space.c,v 1.18 2011/07/20 20:46:49 dyoung Exp $	*/
 
 /*-
  * Copyright (c) 2001, 2002 The NetBSD Foundation, Inc.
@@ -27,7 +27,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: bus_space.c,v 1.17 2011/07/19 15:30:53 dyoung Exp $);
+__KERNEL_RCSID(0, $NetBSD: bus_space.c,v 1.18 2011/07/20 20:46:49 dyoung Exp $);
 
 #include debug_hpcsh.h
 
@@ -44,136 +44,7 @@
 #endif
 #include machine/debug.h
 
-/*
- * Utility macros; INTERNAL USE ONLY.
- */
-
-#define	__TYPENAME(BITS)	u_int##BITS##_t
-
-#define _BUS_SPACE_READ(PREFIX, BYTES, BITS)\
-__TYPENAME(BITS)			\
-PREFIX##_read_##BYTES(void *, bus_space_handle_t,  bus_size_t);		\
-__TYPENAME(BITS)			\
-PREFIX##_read_##BYTES(void *tag, bus_space_handle_t bsh,		\
-		  bus_size_t offset)\
-{	\
-	_BUS_SPACE_ACCESS_HOOK();	\
-	return *(volatile __TYPENAME(BITS) *)(bsh + offset);		\
-}
-
-#define _BUS_SPACE_READ_MULTI(PREFIX, BYTES, BITS)			\
-void\
-PREFIX##_read_multi_##BYTES(void *, bus_space_handle_t,	bus_size_t,	\
-			__TYPENAME(BITS) *,	bus_size_t);		\
-void\
-PREFIX##_read_multi_##BYTES(void *tag, bus_space_handle_t bsh,		\
-			bus_size_t offset, __TYPENAME(BITS) *addr,	\
-			bus_size_t count)\
-{	\
-	volatile __TYPENAME(BITS) *p = (void *)(bsh + offset);		\
-	_BUS_SPACE_ACCESS_HOOK();	\
-	while (count--)			\
-		*addr++ = *p;		\
-}
-
-#define _BUS_SPACE_READ_REGION(PREFIX, BYTES, BITS)			\
-void\
-PREFIX##_read_region_##BYTES(void *, bus_space_handle_t, bus_size_t,	\
-			 __TYPENAME(BITS) *, bus_size_t);		\
-void\
-PREFIX##_read_region_##BYTES(void *tag, bus_space_handle_t bsh,		\
-			 bus_size_t offset, __TYPENAME(BITS) *addr,	\
-			 bus_size_t count)\
-{	\
-	volatile __TYPENAME(BITS) *p = (void *)(bsh + offset);		\
-	_BUS_SPACE_ACCESS_HOOK();	\
-	while (count--)			\
-		*addr++ = *p++;		\
-}
-
-#define _BUS_SPACE_WRITE(PREFIX, BYTES, BITS)\
-void\
-PREFIX##_write_##BYTES(void *, bus_space_handle_t, bus_size_t,		\
-		   __TYPENAME(BITS));\
-void\
-PREFIX##_write_##BYTES(void *tag, bus_space_handle_t bsh,		\
-		   bus_size_t offset, __TYPENAME(BITS) value)	\
-{	\
-	_BUS_SPACE_ACCESS_HOOK();	\
-	*(volatile __TYPENAME(BITS) *)(bsh + offset) = value;		\
-}
-
-#define _BUS_SPACE_WRITE_MULTI(PREFIX, BYTES, BITS)			\
-void\
-PREFIX##_write_multi_##BYTES(void *, bus_space_handle_t, bus_size_t,	\
-			 const __TYPENAME(BITS) *, bus_size_t);	\
-void\
-PREFIX##_write_multi_##BYTES(void *tag, bus_space_handle_t bsh,		\
-			 bus_size_t offset,\
-			

CVS commit: src/sys/dev/usb

2011-07-20 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Wed Jul 20 22:33:46 UTC 2011

Modified Files:
src/sys/dev/usb: usbdevices.config

Log Message:
Bring usbdevices.config in line with i386 GENERIC (this is now a superset).
uhmodem(4) and xboxcontroller(4) have been left commented out, as they do
no appear in GENERIC.  However some ucom(4) drivers that are not in GENERIC
have been added for no particular reason.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/sys/dev/usb/usbdevices.config

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/usbdevices.config
diff -u src/sys/dev/usb/usbdevices.config:1.7 src/sys/dev/usb/usbdevices.config:1.8
--- src/sys/dev/usb/usbdevices.config:1.7	Wed Jul 20 21:08:30 2011
+++ src/sys/dev/usb/usbdevices.config	Wed Jul 20 22:33:46 2011
@@ -1,4 +1,4 @@
-#	$NetBSD: usbdevices.config,v 1.7 2011/07/20 21:08:30 jakllsch Exp $
+#	$NetBSD: usbdevices.config,v 1.8 2011/07/20 22:33:46 jakllsch Exp $
 #
 # This file contains all USB related configuration.
 # It is suitable for inclusion in a kernel config(5) file.
@@ -37,17 +37,31 @@
 ums*	at uhidev? reportid ?
 wsmouse* at ums? mux 0
 
-# USB eGalax touch-panel
-uep*	at uhub? port ?
-wsmouse* at uep? mux 0
-
 # USB Keyboards
 ukbd*	at uhidev? reportid ?
 wskbd*	at ukbd? console ? mux 1
 
+# USB TEMPer and TEMPerHUM
+uthum*	at uhidev? reportid ?
+
+# USB serial adapter
+ucycom* at uhidev? reportid ?
+
 # USB Generic HID devices
 uhid*	at uhidev? reportid ?
 
+# USB eGalax touch-panel
+uep*	at uhub? port ?
+wsmouse* at uep? mux 0
+
+# Xbox controller -- non-standard USB connector
+#xboxcontroller* at uhub? port ?
+#wsmouse* at xboxcontroller? mux 0
+
+# USB LCDs and USB-VGA adapters
+udl*	at uhub? port ?		# DisplayLink DL-1x0/1x5
+wsdisplay* at udl?
+
 # USB Printer
 ulpt*	at uhub? port ? configuration ? interface ?
 
@@ -55,12 +69,16 @@
 umodem*	at uhub? port ? configuration ?
 ucom*	at umodem?
 
+# Option N.V. Wireless WAN modems
+uhso*	at uhub? port ? configuration ?
+
 # USB Mass Storage
 umass*	at uhub? port ? configuration ? interface ?
 wd*	at umass?
 
 # USB audio
 uaudio*	at uhub? port ? configuration ?
+uaudio* at usbifif?
 
 # USB MIDI
 umidi* at uhub? port ? configuration ?
@@ -78,6 +96,10 @@
 ustir* at uhub? port ?
 irframe* at ustir?
 
+# Windows Media Center IR transceiver
+irmce*	at uhub? port ?
+cir*	at irmce?
+
 # USB Ethernet adapters
 aue*	at uhub? port ?		# ADMtek AN986 Pegasus based adapters
 axe*	at uhub? port ?		# ASIX AX88172 based adapters
@@ -86,21 +108,35 @@
 kue*	at uhub? port ?		# Kawasaki LSI KL5KUSB101B based adapters
 udav*	at uhub? port ?		# Davicom DM9601 based adapters
 url*	at uhub? port ?		# Realtek RTL8150L based adapters
+urndis*	at uhub? port ?		# Microsoft RNDIS specification
 
-# USB 802.11b adapters
+# USB 802.11 adapters
 atu*	at uhub? port ?		# Atmel AT76C50XX based adapters
-ral*	at uhub? port ?		# Ralink Technology RT25x0 based adapters
+otus*	at uhub? port ?		# Atheros AR9001U
+ral*	at uhub? port ?		# Ralink Technology RT25x0 802.11a/b/g
+rum*	at uhub? port ?		# Ralink Technology RT2501/RT2601 802.11a/b/g
+upgt*	at uhub? port ?		# Intersil PrismGT
+zyd*	at uhub? port ?		# Zydas ZD1211
 
 # Prolific PL2301/PL2302 host-to-host adapter
 upl*	at uhub? port ?
 
 # Serial adapters
+uark*	at uhub? port ?		# ArkMicroChips 3116 serial adapter
+ucom*	at uark? portno?
+
 ubsa*	at uhub? port ?		# Belkin serial adapter
 ucom*	at ubsa? portno ?
 
+uchcom*	at uhub? port ?		# WinChipHead CH340/CH341 serial adapter
+ucom*	at uchcom? portno ?
+
 uftdi*	at uhub? port ?		# FTDI FT8U100AX serial adapter
 ucom*	at uftdi? portno ?
 
+#uhmodem* at uhub? port ?	# Huawei E220 3G/HSDPA modem
+#ucom* at uhmodem?
+
 uipaq*	at uhub? port ?		# iPAQ PDAs
 ucom*	at uipaq? portno ?
 
@@ -110,11 +146,17 @@
 uplcom* at uhub? port ? 	# I/O DATA USB-RSAQ2 serial adapter
 ucom*	at uplcom? portno ?
 
+uslsa*	at uhub? port ?		# Silicon Labs serial adapters
+ucom*	at uslsa? portno ?
+
 uvscom* at uhub? port ? 	# SUNTAC Slipper U VS-10U serial adapter
 ucom*	at uvscom? portno ?
 
-uslsa*	at uhub? port ? 	# Silicon Labs CP210x serial adapter
-ucom*	at uslsa? portno ?
+moscom* at uhub? port ? 	# Moschip MCS7xxx serial adaapter
+ucom*	at moscom? portno ?
+
+# RIM BlackBerry
+uberry* at uhub? port ?
 
 # Diamond Multimedia Rio 500
 urio*	at uhub? port ?
@@ -146,5 +188,24 @@
 # USB Generic driver
 ugen*	at uhub? port ?
 
-###
-###
+# USB 3G datacards
+u3ginit* at uhub? port?
+u3g*	at uhub? port ?
+ucom*	at u3g?
+
+# USB generic serial port (e.g., data over cellular)
+ugensa*	at uhub? port ?
+ucom*	at ugensa?
+
+# USB Video capture devices
+
+pseye*	at uhub?		# Sony PLAYSTATION(R) Eye webcam
+uvideo* at uhub?		# USB Video Class capture devices
+auvitek* at uhub?		# Auvitek AU0828 video capture devices
+emdtv* at uhub?			# Empia EM28xx video capture devices
+video* at videobus?
+dtv* at dtvbus?
+
+# USB 

CVS commit: src/sys/dev/bluetooth

2011-07-20 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Wed Jul 20 22:42:59 UTC 2011

Added Files:
src/sys/dev/bluetooth: bluetoothdevices.config

Log Message:
Add config(5) fragment for MI bluetooth(4) drivers.


To generate a diff of this commit:
cvs rdiff -u -r0 -r1.1 src/sys/dev/bluetooth/bluetoothdevices.config

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Added files:

Index: src/sys/dev/bluetooth/bluetoothdevices.config
diff -u /dev/null src/sys/dev/bluetooth/bluetoothdevices.config:1.1
--- /dev/null	Wed Jul 20 22:42:59 2011
+++ src/sys/dev/bluetooth/bluetoothdevices.config	Wed Jul 20 22:42:59 2011
@@ -0,0 +1,46 @@
+# $NetBSD: bluetoothdevices.config,v 1.1 2011/07/20 22:42:59 jakllsch Exp $
+#
+# Bluetooth devices for config(5) file inclusion.
+
+# Bluetooth Controller and Device support
+
+# Bluetooth PCMCIA Controllers
+#bt3c* at pcmcia? function ?		# 3Com 3CRWB6096-A
+#btbc* at pcmcia? function ?		# AnyCom BlueCard LSE041/039/139
+
+# Bluetooth SDIO Controller
+#sbt* at sdmmc?
+
+# Bluetooth USB Controllers
+#ubt* at uhub? port ?
+
+# Bluetooth Device Hub
+#bthub* at bcsp?
+#bthub* at bt3c?
+#bthub* at btbc?
+#bthub* at btuart?
+#bthub* at sbt?
+#bthub* at ubt?
+
+
+# Bluetooth HID support
+bthidev* at bthub?
+
+# Bluetooth Mouse
+btms* at bthidev? reportid ?
+wsmouse* at btms? mux 0
+
+# Bluetooth Keyboard
+btkbd* at bthidev? reportid ?
+wskbd* at btkbd? console ? mux 1
+
+# Bluetooth Apple Magic Mouse
+btmagic* at bthub?
+wsmouse* at btmagic? mux 0
+
+# Bluetooth Audio support
+btsco* at bthub?
+
+# Bluetooth pseudo devices
+pseudo-device	bcsp			# BlueCore Serial Protocol
+pseudo-device	btuart			# Bluetooth HCI UART (H4)



CVS commit: src/sys/arch/evbarm/conf

2011-07-20 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Wed Jul 20 22:53:38 UTC 2011

Added Files:
src/sys/arch/evbarm/conf: MV2120 mk.mv2120 std.mv2120

Log Message:
Add support for HP Media Vault MV2100/MV5100 series Marvell Orion board.


To generate a diff of this commit:
cvs rdiff -u -r0 -r1.1 src/sys/arch/evbarm/conf/MV2120 \
src/sys/arch/evbarm/conf/mk.mv2120 src/sys/arch/evbarm/conf/std.mv2120

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Added files:

Index: src/sys/arch/evbarm/conf/MV2120
diff -u /dev/null src/sys/arch/evbarm/conf/MV2120:1.1
--- /dev/null	Wed Jul 20 22:53:38 2011
+++ src/sys/arch/evbarm/conf/MV2120	Wed Jul 20 22:53:38 2011
@@ -0,0 +1,360 @@
+#	$NetBSD: MV2120,v 1.1 2011/07/20 22:53:38 jakllsch Exp $
+#
+#  This configuration supports for HP MV2120/MV5140/MV5150.
+
+include 	arch/evbarm/conf/std.mv2120
+
+options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
+
+options SYMTAB_SPACE=92
+
+options		DIAGNOSTIC
+options		LOCKDEBUG
+
+makeoptions	DEBUG=-g
+
+# estimated number of users
+
+maxusers	32
+
+# Board Type
+makeoptions BOARDTYPE=mv2120
+options EVBARM_BOARDTYPE=mv2120
+
+# CPU options
+options		CPU_ARM9E
+makeoptions	CPUFLAGS=-mcpu=arm926ej-s -O2
+
+# Marvell SoC options
+options 	ORION
+
+# Standard system options
+
+options		MSGBUFSIZE=32768
+
+options 	RTC_OFFSET=0	# hardware clock is this many mins. west of GMT
+options 	NTP		# NTP phase/frequency locked loop
+
+# File systems
+
+file-system 	FFS		# UFS
+file-system 	EXT2FS		# second extended file system (linux)
+file-system 	LFS		# log-structured file system
+file-system 	MFS		# memory file system
+file-system 	NFS		# Network File System client
+file-system 	NTFS		# Windows/NT file system (experimental)
+file-system 	CD9660		# ISO 9660 + Rock Ridge file system
+file-system 	MSDOSFS		# MS-DOS file system
+file-system 	FDESC		# /dev/fd
+file-system 	KERNFS		# /kern
+file-system 	NULLFS		# loopback file system
+file-system 	OVERLAY		# overlay file system
+file-system 	PUFFS		# Userspace file systems (e.g. ntfs-3g  sshfs)
+file-system 	PROCFS		# /proc
+file-system 	UMAPFS		# NULLFS + uid and gid remapping
+file-system 	UNION		# union file system
+file-system 	CODA		# Coda File System; also needs vcoda (below)
+file-system 	SMBFS		# experimental - CIFS; also needs nsmb (below)
+file-system 	PTYFS		# /dev/ptm support
+file-system 	TMPFS		# Efficient memory file-system
+file-system 	UDF		# experimental - OSTA UDF CD/DVD file-system
+file-system 	HFS		# experimental - Apple HFS+ (read-only)
+
+# File system options
+options 	QUOTA		# UFS quotas
+#options 	FFS_EI		# FFS Endian Independent support
+options 	WAPBL		# File system journaling support - Experimental
+# Note that UFS_DIRHASH is suspected of causing kernel memory corruption.
+# It is not recommended for general use.
+#options 	UFS_DIRHASH	# UFS Large Directory Hashing - Experimental
+options 	NFSSERVER	# Network File System server
+#options 	FFS_NO_SNAPSHOT	# No FFS snapshot support
+#options 	EXT2FS_SYSTEM_FLAGS # makes ext2fs file flags (append and
+# immutable) behave as system flags.
+
+# Networking options
+
+options TCP_CSUM_COUNTERS
+options UDP_CSUM_COUNTERS
+
+#options 	GATEWAY		# packet forwarding
+options 	INET		# IP + ICMP + TCP + UDP
+options 	INET6		# IPv6
+#options 	IPSEC		# IP security
+#options 	IPSEC_ESP	# IP security (encryption part; define w/IPSEC)
+#options 	IPSEC_NAT_T	# IPsec NAT traversal (NAT-T)
+#options 	IPSEC_DEBUG	# debug for IP security
+#options 	MROUTING	# IP multicast routing
+#options 	PIM		# Protocol Independent Multicast
+#options 	ISO,TPIP	# OSI
+#options 	EON		# OSI tunneling over IP
+#options 	NETATALK	# AppleTalk networking protocols
+options 	PPP_BSDCOMP	# BSD-Compress compression support for PPP
+options 	PPP_DEFLATE	# Deflate compression support for PPP
+options 	PPP_FILTER	# Active filter support for PPP (requires bpf)
+options 	PFIL_HOOKS	# pfil(9) packet filter hooks
+options 	IPFILTER_LOG	# ipmon(8) log support
+options 	IPFILTER_LOOKUP	# ippool(8) support
+options 	IPFILTER_COMPAT	# Compat for IP-Filter
+#options 	IPFILTER_DEFAULT_BLOCK	# block all packets by default
+#options 	TCP_DEBUG	# Record last TCP_NDEBUG packets with SO_DEBUG
+
+options 	NFS_BOOT_BOOTP
+#options 	NFS_BOOT_BOOTPARAM
+options 	NFS_BOOT_DHCP
+options		NFS_BOOT_TCP
+
+# Compatibility options
+
+#options 	COMPAT_09	# NetBSD 0.9 compatibility.
+#options 	COMPAT_10	# NetBSD 1.0 compatibility.
+#options 	COMPAT_11	# NetBSD 1.1 compatibility.
+#options 	COMPAT_12	# NetBSD 1.2 compatibility.
+#options 	COMPAT_13	# NetBSD 1.3 compatibility.
+#options 	COMPAT_14	# NetBSD 1.4 compatibility.
+#options 	COMPAT_15	# NetBSD 1.5 compatibility.
+options 	COMPAT_16	# NetBSD 1.6 compatibility.
+options 	COMPAT_20	# NetBSD 2.0 compatibility.
+options 	COMPAT_30	# NetBSD 3.0 compatibility.
+options 	COMPAT_40	# NetBSD 4.0 compatibility.
+#options 	

CVS commit: src/tests/lib/libc/sys

2011-07-20 Thread Jean-Yves Migeon
Module Name:src
Committed By:   jym
Date:   Wed Jul 20 22:53:44 UTC 2011

Modified Files:
src/tests/lib/libc/sys: t_mprotect.c

Log Message:
Modify exec test to be more resilient regarding partial exec protection:
skip test instead of returning a failure that could be misinterpreted.

Suggested by Jukka in private mail.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/tests/lib/libc/sys/t_mprotect.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/gpl3/gcc/usr.bin/backend/Makefile
diff -u src/external/gpl3/gcc/usr.bin/backend/Makefile:1.11 src/external/gpl3/gcc/usr.bin/backend/Makefile:1.12
--- src/external/gpl3/gcc/usr.bin/backend/Makefile:1.11	Tue Jul 19 15:59:01 2011
+++ src/external/gpl3/gcc/usr.bin/backend/Makefile	Thu Jul 21 03:01:26 2011
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.11 2011/07/19 15:59:01 tron Exp $
+#	$NetBSD: Makefile,v 1.12 2011/07/21 03:01:26 mrg Exp $
 
 LIBISPRIVATE=	yes
 
@@ -303,11 +303,15 @@
 cgraphunit.d cgraphunit.o: gcov-io.h
 vec.lo: gtype-desc.h
 gtype-desc.d gtype-desc.o: insn-constants.h
-# XXX
+insn-emit.d insn-emit.o: tm-constrs.h
+
+.if ${MACHINE_CPU} == arm
+arm.d arm.o: insn-constants.h tm_p.h
+.endif
+
 .if ${MACHINE_ARCH} == i386 || ${MACHINE_ARCH} == x86_64
 i386.d i386.o: tm-constrs.h
 .endif
-insn-emit.d insn-emit.o: tm-constrs.h
 
 CFLAGS+=	-Wno-stack-protector
 



CVS commit: src/distrib/sets/lists/comp

2011-07-20 Thread matthew green
Module Name:src
Committed By:   mrg
Date:   Thu Jul 21 03:05:13 UTC 2011

Modified Files:
src/distrib/sets/lists/comp: ad.armeb

Log Message:
obsolete arm/bus.h for armeb as well.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/distrib/sets/lists/comp/ad.armeb

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/comp/ad.armeb
diff -u src/distrib/sets/lists/comp/ad.armeb:1.4 src/distrib/sets/lists/comp/ad.armeb:1.5
--- src/distrib/sets/lists/comp/ad.armeb:1.4	Sun Jul 17 20:54:30 2011
+++ src/distrib/sets/lists/comp/ad.armeb	Thu Jul 21 03:05:13 2011
@@ -1,4 +1,4 @@
-# $NetBSD: ad.armeb,v 1.4 2011/07/17 20:54:30 joerg Exp $
+# $NetBSD: ad.armeb,v 1.5 2011/07/21 03:05:13 mrg Exp $
 #
 # The armeb MACHINE_ARCH never existed in NetBSD as a.out, so we
 #	skip the old a.out compatibility tools.
@@ -27,7 +27,7 @@
 ./usr/include/arm/asm.hcomp-c-include
 ./usr/include/arm/atomic.h			comp-c-include
 ./usr/include/arm/bswap.h			comp-c-include
-./usr/include/arm/bus.hcomp-c-include
+./usr/include/arm/bus.hcomp-obsolete		obsolete
 ./usr/include/arm/byte_swap.h			comp-c-include
 ./usr/include/arm/cdefs.h			comp-c-include
 ./usr/include/arm/cpu.hcomp-c-include



CVS commit: src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax

2011-07-20 Thread matthew green
Module Name:src
Committed By:   mrg
Date:   Thu Jul 21 03:10:24 UTC 2011

Modified Files:
src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax: c++config.h config.h

Log Message:
regenerate.


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.4 \
src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax/c++config.h \
src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax/config.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax/c++config.h
diff -u src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax/c++config.h:1.3 src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax/c++config.h:1.4
--- src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax/c++config.h:1.3	Wed Jul 20 00:53:58 2011
+++ src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax/c++config.h	Thu Jul 21 03:10:24 2011
@@ -499,7 +499,7 @@
 /* #undef _GLIBCXX_HAVE_FABSL */
 
 /* Define to 1 if you have the fenv.h header file. */
-/* #undef _GLIBCXX_HAVE_FENV_H */
+#define _GLIBCXX_HAVE_FENV_H 1
 
 /* Define to 1 if you have the `finite' function. */
 #define _GLIBCXX_HAVE_FINITE 1
Index: src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax/config.h
diff -u src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax/config.h:1.3 src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax/config.h:1.4
--- src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax/config.h:1.3	Wed Jul 20 00:53:58 2011
+++ src/external/gpl3/gcc/lib/libstdc++-v3/arch/vax/config.h	Thu Jul 21 03:10:24 2011
@@ -120,7 +120,7 @@
 /* #undef HAVE_FABSL */
 
 /* Define to 1 if you have the fenv.h header file. */
-/* #undef HAVE_FENV_H */
+#define HAVE_FENV_H 1
 
 /* Define to 1 if you have the `finite' function. */
 #define HAVE_FINITE 1



CVS commit: src/x11/lib/GLU

2011-07-20 Thread matthew green
Module Name:src
Committed By:   mrg
Date:   Thu Jul 21 03:36:29 UTC 2011

Modified Files:
src/x11/lib/GLU: Makefile

Log Message:
apply some -Wno-error.  there are char * vs. const char * issues that
GCC 4.5 complains about, that are fixed in newer eg, MesaLib.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/x11/lib/GLU/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/x11/lib/GLU/Makefile
diff -u src/x11/lib/GLU/Makefile:1.7 src/x11/lib/GLU/Makefile:1.8
--- src/x11/lib/GLU/Makefile:1.7	Sat Sep 24 13:51:46 2005
+++ src/x11/lib/GLU/Makefile	Thu Jul 21 03:36:29 2011
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.7 2005/09/24 13:51:46 chs Exp $
+#	$NetBSD: Makefile,v 1.8 2011/07/21 03:36:29 mrg Exp $
 
 NOLINT=		1	# XTODO: tess.ln SIGSEGVs lint :(
 
@@ -68,3 +68,9 @@
 
 .include bsd.x11.mk
 .include bsd.lib.mk
+
+# Many const char * vs char * issues in xsrc/xfree
+.if defined(HAVE_GCC)  ${HAVE_GCC} = 45
+# XXX -Wno-deprecated doesn't work?
+CXXFLAGS+=	-Wno-error
+.endif



CVS commit: src/sys/arch/amd64/conf

2011-07-20 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Thu Jul 21 04:00:26 UTC 2011

Modified Files:
src/sys/arch/amd64/conf: GENERIC

Log Message:
Add dtv* at dtvbus? because I'll get weird looks if I introduce a #if NDTV  0,
and also if I don't un-Break the build.


To generate a diff of this commit:
cvs rdiff -u -r1.324 -r1.325 src/sys/arch/amd64/conf/GENERIC

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/amd64/conf/GENERIC
diff -u src/sys/arch/amd64/conf/GENERIC:1.324 src/sys/arch/amd64/conf/GENERIC:1.325
--- src/sys/arch/amd64/conf/GENERIC:1.324	Wed Jul 20 20:29:54 2011
+++ src/sys/arch/amd64/conf/GENERIC	Thu Jul 21 04:00:25 2011
@@ -1,4 +1,4 @@
-# $NetBSD: GENERIC,v 1.324 2011/07/20 20:29:54 jakllsch Exp $
+# $NetBSD: GENERIC,v 1.325 2011/07/21 04:00:25 jakllsch Exp $
 #
 # GENERIC machine description file
 #
@@ -22,7 +22,7 @@
 
 options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-#ident 		GENERIC-$Revision: 1.324 $
+#ident 		GENERIC-$Revision: 1.325 $
 
 maxusers	64		# estimated number of users
 
@@ -1029,6 +1029,7 @@
 pseye* at uhub?		# Sony PLAYSTATION(R) Eye webcam
 uvideo* at uhub?	# USB Video Class capture devices
 video* at videobus?
+dtv* at dtvbus?
 
 
 # TV cards



CVS commit: src/sys/arch/amd64/conf

2011-07-20 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Thu Jul 21 04:05:14 UTC 2011

Modified Files:
src/sys/arch/amd64/conf: GENERIC

Log Message:
Add wmieeepc(4) to amd64 GENERIC.


To generate a diff of this commit:
cvs rdiff -u -r1.325 -r1.326 src/sys/arch/amd64/conf/GENERIC

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/amd64/conf/GENERIC
diff -u src/sys/arch/amd64/conf/GENERIC:1.325 src/sys/arch/amd64/conf/GENERIC:1.326
--- src/sys/arch/amd64/conf/GENERIC:1.325	Thu Jul 21 04:00:25 2011
+++ src/sys/arch/amd64/conf/GENERIC	Thu Jul 21 04:05:14 2011
@@ -1,4 +1,4 @@
-# $NetBSD: GENERIC,v 1.325 2011/07/21 04:00:25 jakllsch Exp $
+# $NetBSD: GENERIC,v 1.326 2011/07/21 04:05:14 jakllsch Exp $
 #
 # GENERIC machine description file
 #
@@ -22,7 +22,7 @@
 
 options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-#ident 		GENERIC-$Revision: 1.325 $
+#ident 		GENERIC-$Revision: 1.326 $
 
 maxusers	64		# estimated number of users
 
@@ -318,6 +318,7 @@
 wb*		at acpi?		# Winbond W83L518D SD/MMC reader
 sdmmc*		at wb?			# SD/MMC bus
 wmidell*	at acpiwmibus?		# Dell WMI mappings
+wmieeepc*	at acpiwmibus?		# Asus Eee PC WMI mappings
 wmihp*		at acpiwmibus?		# HP WMI mappings
 wmimsi* 	at acpiwmibus?		# MSI WMI mappings
Index: src/tests/lib/libc/sys/t_mprotect.c
diff -u src/tests/lib/libc/sys/t_mprotect.c:1.2 src/tests/lib/libc/sys/t_mprotect.c:1.3
--- src/tests/lib/libc/sys/t_mprotect.c:1.2	Mon Jul 18 23:16:11 2011
+++ src/tests/lib/libc/sys/t_mprotect.c	Wed Jul 20 22:53:44 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: t_mprotect.c,v 1.2 2011/07/18 23:16:11 jym Exp $ */
+/* $NetBSD: t_mprotect.c,v 1.3 2011/07/20 22:53:44 jym Exp $ */
 
 /*-
  * Copyright (c) 2011 The NetBSD Foundation, Inc.
@@ -29,7 +29,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include sys/cdefs.h
-__RCSID($NetBSD: t_mprotect.c,v 1.2 2011/07/18 23:16:11 jym Exp $);
+__RCSID($NetBSD: t_mprotect.c,v 1.3 2011/07/20 22:53:44 jym Exp $);
 
 #include sys/param.h
 #include sys/mman.h
@@ -224,21 +224,23 @@
 
 	(void)wait(sta);
 
+	ATF_REQUIRE(munmap(map, page) == 0);
+
 	ATF_REQUIRE(WIFEXITED(sta) != 0);
 
 	switch (xp_support) {
 	case PARTIAL_XP:
-		/* Partial protection might fail: indicate it */
-		ATF_CHECK_MSG(WEXITSTATUS(sta) == SIGSEGV,
-		Host only supports partial executable space protection);
+		/* Partial protection might fail; skip the test when it does */
+		if (WEXITSTATUS(sta) != SIGSEGV) {
+			atf_tc_skip(Host only supports 
+			partial executable space protection);
+		}
 		break;
 	case PERPAGE_XP: default:
 		/* Per-page --x protection should not fail */
 		ATF_REQUIRE(WEXITSTATUS(sta) == SIGSEGV);
 		break;
 	}
-
-	ATF_REQUIRE(munmap(map, page) == 0);
 }
 
 ATF_TC(mprotect_pax);



CVS commit: src/external/gpl3/gcc/usr.bin/backend

2011-07-20 Thread matthew green
Module Name:src
Committed By:   mrg
Date:   Thu Jul 21 03:01:26 UTC 2011

Modified Files:
src/external/gpl3/gcc/usr.bin/backend: Makefile

Log Message:
add some missing dependancies.  there are probably a bunch more make
hasn't spat at me yet.


To generate a diff of this commit:
cvs rdiff -u -r1.11 -r1.12 src/external/gpl3/gcc/usr.bin/backend/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
